@@ -1091,15 +1091,6 @@ insert_report_host_detail (report_t, const char *, const char *, const char *,
                            const char *, const char *, const char *,
                            const char *);
 
-void
-hosts_set_identifiers (report_t);
-
-void
-hosts_set_max_severity (report_t, int*, int*);
-
-void
-hosts_set_details (report_t report);
-
 void
 clear_duration_schedules (task_t);
 
@@ -2284,9 +2275,6 @@ host_t
 host_notice (const char *, const char *, const char *, const char *,
              const char *, int, int);
 
-int
-init_asset_host_iterator (iterator_t *, const get_data_t *);
-
 int
 init_resource_names_host_iterator (iterator_t *iterator, get_data_t *get);
 
@@ -2296,36 +2284,12 @@ asset_iterator_writable (iterator_t *);
 int
 asset_iterator_in_use (iterator_t *);
 
-const char*
-asset_host_iterator_severity (iterator_t *);
-
 int
 asset_host_count (const get_data_t *);
 
-int
-init_asset_os_iterator (iterator_t *, const get_data_t *);
-
 int
 init_resource_names_os_iterator (iterator_t *, get_data_t *);
 
-const char*
-asset_os_iterator_title (iterator_t *);
-
-int
-asset_os_iterator_installs (iterator_t *);
-
-const char*
-asset_os_iterator_latest_severity (iterator_t *);
-
-const char*
-asset_os_iterator_highest_severity (iterator_t *);
-
-const char*
-asset_os_iterator_average_severity (iterator_t *);
-
-int
-asset_os_iterator_all_installs (iterator_t *);
-
 int
 asset_os_count (const get_data_t *);
 
