@@ -628,3 +628,25 @@ should_sync_configs ()
   g_dir_close (dir);
   return FALSE;
 }
+
+/**
+ * @brief Returns TRUE if the scanner type requires a scan configuration.
+ *
+ * @param[in] scanner_type  The scanner type enum.
+ *
+ * @return TRUE if config is required, FALSE otherwise.
+ */
+gboolean
+scanner_type_requires_config (int scanner_type)
+{
+  switch (scanner_type)
+    {
+    case SCANNER_TYPE_CVE:
+    case SCANNER_TYPE_AGENT_CONTROLLER:
+    case SCANNER_TYPE_AGENT_CONTROLLER_SENSOR:
+      return FALSE;
+
+    default:
+      return TRUE;
+    }
+}
