@@ -19,12 +19,10 @@
 #ifndef _GVMD_MANAGE_CONFIGS_H
 #define _GVMD_MANAGE_CONFIGS_H
 
-#include "iterator.h"
+#include "manage_resources.h"
 #include "manage_get.h"
 #include "manage_preferences.h"
 
-typedef resource_t config_t;
-
 preference_t *
 get_nvt_preference_by_id (const char *,
                           const char *,
@@ -168,4 +166,7 @@ manage_rebuild_configs ();
 gboolean
 should_sync_configs ();
 
+gboolean
+scanner_type_requires_config (int scanner_type);
+
 #endif /* not _GVMD_MANAGE_CONFIGS_H */
