@@ -17,7 +17,7 @@
  */
 
 /**
- * @file  manage_migrators.c
+ * @file
  * @brief The Greenbone Vulnerability Manager DB Migrators file.
  *
  * This file defines the functions used by the manager to migrate the DB to the
@@ -3347,6 +3347,108 @@ migrate_258_to_259 ()
   return 0;
 }
 
+/**
+ * @brief Migrate the database from version 259 to version 260.
+ *
+ * @return 0 success, -1 error.
+ */
+int
+migrate_259_to_260 ()
+{
+  sql_begin_immediate ();
+
+  /* Ensure that the database is currently version 259. */
+
+  if (manage_db_version () != 259)
+    {
+      sql_rollback ();
+      return -1;
+    }
+
+  /* Update the database. */
+
+  // Add processing_required and in_assets fields to reports
+
+  sql ("ALTER TABLE reports ADD COLUMN processing_required integer DEFAULT 0;");
+  sql ("ALTER TABLE reports ADD COLUMN in_assets integer;");
+ 
+  /* Set the database version to 260. */
+
+  set_db_version (260);
+
+  sql_commit ();
+
+  return 0;
+}
+
+/**
+ * @brief Migrate the database from version 260 to version 261.
+ *
+ * @return 0 success, -1 error.
+ */
+int
+migrate_260_to_261 ()
+{
+  sql_begin_immediate ();
+
+  /* Ensure that the database is currently version 260. */
+
+  if (manage_db_version () != 260)
+    {
+      sql_rollback ();
+      return -1;
+    }
+
+  /* Update the database. */
+
+  // Add oci_image_target and oci_image_target_location fields to tasks
+
+  sql ("ALTER TABLE tasks ADD COLUMN oci_image_target integer;");
+  sql ("ALTER TABLE tasks ADD COLUMN oci_image_target_location integer;");
+
+  /* Set the database version to 261. */
+
+  set_db_version (261);
+
+  sql_commit ();
+
+  return 0;
+}
+
+/**
+ * @brief Migrate the database from version 261 to version 262.
+ *
+ * @return 0 success, -1 error.
+ */
+int
+migrate_261_to_262 ()
+{
+  sql_begin_immediate ();
+
+  /* Ensure that the database is currently version 261. */
+
+  if (manage_db_version () != 261)
+    {
+      sql_rollback ();
+      return -1;
+    }
+
+  /* Update the database. */
+
+  // Add agent_group_target and agent_group_name fields to tasks
+
+  sql ("ALTER TABLE tasks ADD COLUMN agent_group integer;");
+  sql ("ALTER TABLE tasks ADD COLUMN agent_group_location integer;");
+
+  /* Set the database version to 262. */
+
+  set_db_version (262);
+
+  sql_commit ();
+
+  return 0;
+}
+
 #undef UPDATE_DASHBOARD_SETTINGS
 
 /**
@@ -3412,6 +3514,9 @@ static migrator_t database_migrators[] = {
   {257, migrate_256_to_257},
   {258, migrate_257_to_258},
   {259, migrate_258_to_259},
+  {260, migrate_259_to_260},
+  {261, migrate_260_to_261},
+  {262, migrate_261_to_262},
   /* End marker. */
   {-1, NULL}};
 
