@@ -412,6 +412,19 @@ init_get_iterator (iterator_t*, const char *, const get_data_t *, column_t *,
                    column_t *, const char **, int, const char *, const char *,
                    int);
 
+int
+init_get_iterator2 (iterator_t *, const char *, const get_data_t *, column_t *,
+                    column_t *, column_t *, column_t *, const char **, int,
+                    const char *, const char *, const char *, int, int,
+                    const char *);
+
+int
+init_get_iterator2_with (iterator_t *, const char *, const get_data_t *,
+                         column_t *, column_t *, column_t *, column_t *,
+                         const char **, int, const char *, const char *,
+                         const char *, int, int, const char *, const char *,
+                         int, int);
+
 int
 openvasd_get_details_from_iterator (iterator_t *, char **, GSList **);
 
@@ -497,6 +510,9 @@ setting_value_sql (const char *, char **);
 int
 setting_value_int_sql (const char *, int *);
 
+int
+setting_dynamic_severity_int ();
+
 void
 add_role_permission_resource (const gchar *, const gchar *, const gchar *,
                               const gchar *);
@@ -513,6 +529,9 @@ create_view_result_vt_epss ();
 int
 config_family_entire_and_growing (config_t, const char*);
 
+gchar *
+new_severity_clause (int, int);
+
 void
 reports_clear_count_cache_dynamic ();
 
