@@ -17,7 +17,7 @@
  */
 
 /**
- * @file manage_sql_nvts.h
+ * @file
  * @brief Manager Manage library: SQL backend headers.
  */
 
@@ -151,7 +151,7 @@ int
 update_or_rebuild_nvts (int);
 
 int
-nvts_feed_version_status ();
+nvts_feed_version_status_from_scanner ();
 
 char *
 nvt_family (const char *);
@@ -159,4 +159,13 @@ nvt_family (const char *);
 int
 family_count ();
 
+
+#if FEED_VT_METADATA == 1
+int
+manage_update_nvts_from_feed (gboolean);
+
+int
+nvts_feed_version_status_from_timestamp ();
+#endif
+
 #endif /* not _GVMD_MANAGE_SQL_NVTS_H */
